timi_uuid
=======

timi_uuid is a lightweight Python library for sensibly dealing with UUID5 (or Time Random UUIDs as we like to sometimes call them). It allows you to create UUID str in a variety of different ways. Take a look at `the docs <http://packages.python.org/timi-uuid>`_ for the interface.

Who/What/When/Where
-------------------

Author: Timi long (`@timilong <http://blog.timilong.com>`_)

PyPi: `http://pypi.python.org/pypi/timi-uuid/ <http://pypi.python.org/pypi/timi-uuid/>`_

Docs: `http://packages.python.org/timi-uuid/ <http://packages.python.org/timi-uuid/>`_

License: MIT License

I am definitely open to contributions. Please feel free to submit your lock implementation.
